"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClusterType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClusterTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClusterType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ClusterType.ValueType  # 0
    K8S: _ClusterType.ValueType  # 1
    ECS: _ClusterType.ValueType  # 2
    FAKE: _ClusterType.ValueType  # 3
    EXTENSION: _ClusterType.ValueType  # 4

class ClusterType(_ClusterType, metaclass=_ClusterTypeEnumTypeWrapper): ...

UNKNOWN: ClusterType.ValueType  # 0
K8S: ClusterType.ValueType  # 1
ECS: ClusterType.ValueType  # 2
FAKE: ClusterType.ValueType  # 3
EXTENSION: ClusterType.ValueType  # 4
global___ClusterType = ClusterType

class ClusterAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ECSAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCESS_KEY_FIELD_NUMBER: builtins.int
        SECRET_KEY_FIELD_NUMBER: builtins.int
        REGION_FIELD_NUMBER: builtins.int
        ASSUME_ROLE_ARN_FIELD_NUMBER: builtins.int
        CLUSTER_ARN_FIELD_NUMBER: builtins.int
        access_key: builtins.str
        secret_key: builtins.str
        region: builtins.str
        assume_role_arn: builtins.str
        cluster_arn: builtins.str
        def __init__(
            self,
            *,
            access_key: builtins.str = ...,
            secret_key: builtins.str = ...,
            region: builtins.str = ...,
            assume_role_arn: builtins.str = ...,
            cluster_arn: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "assume_role_arn", b"assume_role_arn", "cluster_arn", b"cluster_arn", "region", b"region", "secret_key", b"secret_key"]) -> None: ...

    class K8sAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AgentEnvEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        AGENT_ENV_FIELD_NUMBER: builtins.int
        @property
        def agent_env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
        def __init__(
            self,
            *,
            agent_env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["agent_env", b"agent_env"]) -> None: ...

    ENDPOINT_FIELD_NUMBER: builtins.int
    CA_CERT_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    ECS_FIELD_NUMBER: builtins.int
    K8S_FIELD_NUMBER: builtins.int
    K8S_AGENT_AUTH_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    ca_cert: builtins.str
    token: builtins.str
    service_account: builtins.str
    @property
    def ecs(self) -> global___ClusterAuth.ECSAuth: ...
    @property
    def k8s(self) -> global___ClusterAuth.K8sAuth: ...
    k8s_agent_auth: builtins.bool
    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        ca_cert: builtins.str = ...,
        token: builtins.str = ...,
        service_account: builtins.str = ...,
        ecs: global___ClusterAuth.ECSAuth | None = ...,
        k8s: global___ClusterAuth.K8sAuth | None = ...,
        k8s_agent_auth: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ecs", b"ecs", "k8s", b"k8s"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ca_cert", b"ca_cert", "ecs", b"ecs", "endpoint", b"endpoint", "k8s", b"k8s", "k8s_agent_auth", b"k8s_agent_auth", "service_account", b"service_account", "token", b"token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_oneof", b"auth_oneof"]) -> typing_extensions.Literal["ecs", "k8s"] | None: ...

global___ClusterAuth = ClusterAuth

class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Origin:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OriginEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Origin.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Cluster._Origin.ValueType  # 0
        PRODVANA: Cluster._Origin.ValueType  # 1
        """our infra created it"""
        EXTERNAL: Cluster._Origin.ValueType  # 2
        """created externally and added"""

    class Origin(_Origin, metaclass=_OriginEnumTypeWrapper):
        """Origin specifies where the cluster came from."""

    UNKNOWN: Cluster.Origin.ValueType  # 0
    PRODVANA: Cluster.Origin.ValueType  # 1
    """our infra created it"""
    EXTERNAL: Cluster.Origin.ValueType  # 2
    """created externally and added"""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    cluster_id: builtins.str
    origin: global___Cluster.Origin.ValueType
    @property
    def auth(self) -> global___ClusterAuth: ...
    type: global___ClusterType.ValueType
    @property
    def config(self) -> global___ClusterConfig: ...
    @property
    def last_heartbeat_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        origin: global___Cluster.Origin.ValueType = ...,
        auth: global___ClusterAuth | None = ...,
        type: global___ClusterType.ValueType = ...,
        config: global___ClusterConfig | None = ...,
        last_heartbeat_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "cluster_id", b"cluster_id", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp", "name", b"name", "origin", b"origin", "type", b"type"]) -> None: ...

global___Cluster = Cluster

class FakeClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CrashingProgramPatterns(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGE_REGEX_FIELD_NUMBER: builtins.int
        CMD_REGEX_FIELD_NUMBER: builtins.int
        LOG_OUTPUT_FIELD_NUMBER: builtins.int
        image_regex: builtins.str
        cmd_regex: builtins.str
        log_output: builtins.str
        def __init__(
            self,
            *,
            image_regex: builtins.str = ...,
            cmd_regex: builtins.str = ...,
            log_output: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["cmd_regex", b"cmd_regex", "image_regex", b"image_regex", "log_output", b"log_output"]) -> None: ...

    CRASHING_PROGRAMS_FIELD_NUMBER: builtins.int
    @property
    def crashing_programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FakeClusterConfig.CrashingProgramPatterns]: ...
    def __init__(
        self,
        *,
        crashing_programs: collections.abc.Iterable[global___FakeClusterConfig.CrashingProgramPatterns] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crashing_programs", b"crashing_programs"]) -> None: ...

global___FakeClusterConfig = FakeClusterConfig

class ExtensionCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        only used for fetch
        how often to run command after it succeeds
        """
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """how long after a run has started to try another run if it has not completed yet"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionCommand = ExtensionCommand

class ExtensionClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLY_FIELD_NUMBER: builtins.int
    FETCH_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    @property
    def apply(self) -> global___ExtensionCommand: ...
    @property
    def fetch(self) -> global___ExtensionCommand: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    def __init__(
        self,
        *,
        apply: global___ExtensionCommand | None = ...,
        fetch: global___ExtensionCommand | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply", b"apply", "fetch", b"fetch", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply", b"apply", "fetch", b"fetch", "parameters", b"parameters", "proxy_runtime", b"proxy_runtime"]) -> None: ...

global___ExtensionClusterConfig = ExtensionClusterConfig

class CompiledExtensionCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    @property
    def command(self) -> global___ExtensionCommand: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    def __init__(
        self,
        *,
        name_prefix: builtins.str = ...,
        command: global___ExtensionCommand | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "env", b"env", "name_prefix", b"name_prefix", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledExtensionCommand = CompiledExtensionCommand

class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CloudProvider:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig._CloudProvider.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ClusterConfig._CloudProvider.ValueType  # 0
        EKS: ClusterConfig._CloudProvider.ValueType  # 1
        GKE: ClusterConfig._CloudProvider.ValueType  # 2
        AKS: ClusterConfig._CloudProvider.ValueType  # 3
        ONPREM: ClusterConfig._CloudProvider.ValueType  # 4
        OTHER_CLOUD: ClusterConfig._CloudProvider.ValueType  # 5

    class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...
    UNKNOWN: ClusterConfig.CloudProvider.ValueType  # 0
    EKS: ClusterConfig.CloudProvider.ValueType  # 1
    GKE: ClusterConfig.CloudProvider.ValueType  # 2
    AKS: ClusterConfig.CloudProvider.ValueType  # 3
    ONPREM: ClusterConfig.CloudProvider.ValueType  # 4
    OTHER_CLOUD: ClusterConfig.CloudProvider.ValueType  # 5

    class Kubecost(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        KUBECOST_NAMESPACE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        managed: builtins.bool
        kubecost_namespace: builtins.str
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            managed: builtins.bool = ...,
            kubecost_namespace: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kubecost_namespace", b"kubecost_namespace", "managed", b"managed"]) -> None: ...

    class Datadog(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        DATADOG_NAMESPACE_FIELD_NUMBER: builtins.int
        API_KEY_FIELD_NUMBER: builtins.int
        SITE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        managed: builtins.bool
        datadog_namespace: builtins.str
        api_key: builtins.str
        site: builtins.str
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            managed: builtins.bool = ...,
            datadog_namespace: builtins.str = ...,
            api_key: builtins.str = ...,
            site: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "datadog_namespace", b"datadog_namespace", "enabled", b"enabled", "managed", b"managed", "site", b"site"]) -> None: ...

    class ALBIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        INGRESS_CLASS_FIELD_NUMBER: builtins.int
        DEFAULT_BALANCER_ATTRIBUTES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        ingress_class: builtins.str
        @property
        def default_balancer_attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Attributes from https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html#load-balancer-attributes
            that are added to all Ingresses/LBs created in this runtime.
            """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            ingress_class: builtins.str = ...,
            default_balancer_attributes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["default_balancer_attributes", b"default_balancer_attributes", "enabled", b"enabled", "ingress_class", b"ingress_class"]) -> None: ...

    class ArgoRollouts(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AnalysisTemplate(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ArgValue:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ArgValueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType], builtins.type):  # noqa: F821
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 0
                SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 1
                RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 2

            class ArgValue(_ArgValue, metaclass=_ArgValueEnumTypeWrapper): ...
            UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 0
            SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 1
            RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 2

            class ArgMappingEntry(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                key: builtins.str
                value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType
                def __init__(
                    self,
                    *,
                    key: builtins.str = ...,
                    value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

            NAME_FIELD_NUMBER: builtins.int
            ARG_MAPPING_FIELD_NUMBER: builtins.int
            name: builtins.str
            @property
            def arg_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType]:
                """template argument name to prodvana value to inject"""
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                arg_mapping: collections.abc.Mapping[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["arg_mapping", b"arg_mapping", "name", b"name"]) -> None: ...

        ENABLED_FIELD_NUMBER: builtins.int
        TEMPLATES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        @property
        def templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfig.ArgoRollouts.AnalysisTemplate]: ...
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            templates: collections.abc.Iterable[global___ClusterConfig.ArgoRollouts.AnalysisTemplate] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "templates", b"templates"]) -> None: ...

    class GKEIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        CONTAINER_NATIVE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        container_native: builtins.bool
        """Enables container native load balancing, allowing GCP LBs to target k8s pods directly.
        See: https://cloud.google.com/kubernetes-engine/docs/how-to/container-native-load-balancing
        """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            container_native: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["container_native", b"container_native", "enabled", b"enabled"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DISABLE_FLAGGER_FIELD_NUMBER: builtins.int
    DISABLE_ISTIO_FIELD_NUMBER: builtins.int
    KUBECOST_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    ALB_INGRESS_FIELD_NUMBER: builtins.int
    ARGO_ROLLOUTS_FIELD_NUMBER: builtins.int
    GKE_INGRESS_FIELD_NUMBER: builtins.int
    SELF_MANAGED_GKE_INGRESS_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    FAKE_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    disable_flagger: builtins.bool
    disable_istio: builtins.bool
    @property
    def kubecost(self) -> global___ClusterConfig.Kubecost: ...
    @property
    def datadog(self) -> global___ClusterConfig.Datadog: ...
    @property
    def alb_ingress(self) -> global___ClusterConfig.ALBIngress: ...
    @property
    def argo_rollouts(self) -> global___ClusterConfig.ArgoRollouts: ...
    @property
    def gke_ingress(self) -> global___ClusterConfig.GKEIngress: ...
    @property
    def self_managed_gke_ingress(self) -> global___ClusterConfig.GKEIngress:
        """Self-Managed GKE Ingress - exposes configuration options for GKE Ingress
        but does not create an ingress object for you
        """
    cloud_provider: global___ClusterConfig.CloudProvider.ValueType
    @property
    def fake(self) -> global___FakeClusterConfig:
        """only used for fake runtimes"""
    @property
    def extension(self) -> global___ExtensionClusterConfig: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        disable_flagger: builtins.bool = ...,
        disable_istio: builtins.bool = ...,
        kubecost: global___ClusterConfig.Kubecost | None = ...,
        datadog: global___ClusterConfig.Datadog | None = ...,
        alb_ingress: global___ClusterConfig.ALBIngress | None = ...,
        argo_rollouts: global___ClusterConfig.ArgoRollouts | None = ...,
        gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        self_managed_gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        cloud_provider: global___ClusterConfig.CloudProvider.ValueType = ...,
        fake: global___FakeClusterConfig | None = ...,
        extension: global___ExtensionClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "cluster_oneof", b"cluster_oneof", "datadog", b"datadog", "extension", b"extension", "fake", b"fake", "gke_ingress", b"gke_ingress", "kubecost", b"kubecost", "self_managed_gke_ingress", b"self_managed_gke_ingress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "cloud_provider", b"cloud_provider", "cluster_oneof", b"cluster_oneof", "datadog", b"datadog", "disable_flagger", b"disable_flagger", "disable_istio", b"disable_istio", "extension", b"extension", "fake", b"fake", "gke_ingress", b"gke_ingress", "kubecost", b"kubecost", "name", b"name", "self_managed_gke_ingress", b"self_managed_gke_ingress"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cluster_oneof", b"cluster_oneof"]) -> typing_extensions.Literal["fake", "extension"] | None: ...

global___ClusterConfig = ClusterConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ScmType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ScmTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ScmType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ScmType.ValueType  # 0
    GITHUB: _ScmType.ValueType  # 1

class ScmType(_ScmType, metaclass=_ScmTypeEnumTypeWrapper): ...

UNKNOWN: ScmType.ValueType  # 0
GITHUB: ScmType.ValueType  # 1
global___ScmType = ScmType



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/task.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/task.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a\"prodvana/common_config/retry.proto\x1a$prodvana/common_config/program.proto\"\x89\x01\n\nTaskConfig\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\x0cretry_config\x18\x02 \x01(\x0b\x32#.prodvana.common_config.RetryConfig*\x9a\x01\n\rTaskLifecycle\x12\x1a\n\x16UNKNOWN_TASK_LIFECYCLE\x10\x00\x12\x15\n\x11\x43ONVERGENCE_START\x10\x01\x12\x10\n\x0cPRE_APPROVAL\x10\x02\x12\x0c\n\x08\x41PPROVAL\x10\x03\x12\x11\n\rPOST_APPROVAL\x10\x04\x12\x0e\n\nDEPLOYMENT\x10\x05\x12\x13\n\x0fPOST_DEPLOYMENT\x10\x06\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_TASKLIFECYCLE = DESCRIPTOR.enum_types_by_name['TaskLifecycle']
TaskLifecycle = enum_type_wrapper.EnumTypeWrapper(_TASKLIFECYCLE)
UNKNOWN_TASK_LIFECYCLE = 0
CONVERGENCE_START = 1
PRE_APPROVAL = 2
APPROVAL = 3
POST_APPROVAL = 4
DEPLOYMENT = 5
POST_DEPLOYMENT = 6


_TASKCONFIG = DESCRIPTOR.message_types_by_name['TaskConfig']
TaskConfig = _reflection.GeneratedProtocolMessageType('TaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _TASKCONFIG,
  '__module__' : 'prodvana.common_config.task_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.TaskConfig)
  })
_sym_db.RegisterMessage(TaskConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _TASKCONFIG.fields_by_name['program']._options = None
  _TASKCONFIG.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TASKLIFECYCLE._serialized_start=301
  _TASKLIFECYCLE._serialized_end=455
  _TASKCONFIG._serialized_start=161
  _TASKCONFIG._serialized_end=298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/auth/auth_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.auth import auth_pb2 as prodvana_dot_auth_dot_auth__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/auth/auth_manager.proto\x12\rprodvana.auth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x18prodvana/auth/auth.proto\x1a\x1aprodvana/users/users.proto\"g\n\x0fGetTokenRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0credirect_url\x18\x02 \x01(\t\x12\x0f\n\x07\x66or_cli\x18\x03 \x01(\x08\x12\x1f\n\x17prodvana_only_admin_org\x18\x04 \x01(\x08\"&\n\x12GetAuthUrlResponse\x12\x10\n\x08\x61uth_url\x18\x01 \x01(\t\"\x8a\x01\n\x11GetAuthUrlRequest\x12\r\n\x05state\x18\x02 \x01(\t\x12\x0f\n\x07\x66or_cli\x18\x03 \x01(\x08\x12\x12\n\ninvitation\x18\x04 \x01(\t\x12\x1f\n\x17prodvana_only_admin_org\x18\x06 \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06R\x0credirect_urlR\x06no_org\"\x0c\n\nCliAuthReq\"\xe2\x01\n\x0b\x43liAuthResp\x12<\n\x0buser_prompt\x18\x01 \x01(\x0b\x32%.prodvana.auth.CliAuthResp.UserPromptH\x00\x12)\n\x05token\x18\x02 \x01(\x0b\x32\x18.prodvana.auth.AuthTokenH\x00\x1a\\\n\nUserPrompt\x12\x11\n\tuser_code\x18\x01 \x01(\t\x12\x18\n\x10verification_uri\x18\x02 \x01(\t\x12!\n\x19verification_uri_complete\x18\x03 \x01(\tB\x0c\n\nresp_oneof\"l\n\x0fRefreshTokenReq\x12\'\n\x05token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\x0f\n\x07\x66or_cli\x18\x02 \x01(\x08\x12\x1f\n\x17prodvana_only_admin_org\x18\x03 \x01(\x08\"_\n\x10GetAuthTokenResp\x12\'\n\x05token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\"\n\x04user\x18\x02 \x01(\x0b\x32\x14.prodvana.users.User\"\x07\n\x05\x45mpty\"p\n\x14\x43reateOrgApiTokenReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x11\x65xpires_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"U\n\x15\x43reateOrgApiTokenResp\x12\x11\n\tapi_token\x18\x01 \x01(\t\x12)\n\x04info\x18\x02 \x01(\x0b\x32\x1b.prodvana.auth.ApiTokenInfo\"$\n\x14\x44\x65leteOrgApiTokenReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteOrgApiTokenResp\"\x15\n\x13ListOrgApiTokensReq\"C\n\x14ListOrgApiTokensResp\x12+\n\x06tokens\x18\x01 \x03(\x0b\x32\x1b.prodvana.auth.ApiTokenInfo2\xab\x03\n\x0b\x41uthManager\x12k\n\x0cGetAuthToken\x12\x1e.prodvana.auth.GetTokenRequest\x1a\x1f.prodvana.auth.GetAuthTokenResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/auth/get_token\x12p\n\nGetAuthUrl\x12 .prodvana.auth.GetAuthUrlRequest\x1a!.prodvana.auth.GetAuthUrlResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/auth/get_auth_url\x12w\n\x0cRefreshToken\x12\x1e.prodvana.auth.RefreshTokenReq\x1a\x1f.prodvana.auth.GetAuthTokenResp\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/auth/refresh_auth_token:\x01*\x12\x44\n\x07\x43liAuth\x12\x19.prodvana.auth.CliAuthReq\x1a\x1a.prodvana.auth.CliAuthResp\"\x00\x30\x01\x32i\n\x12\x41uthSessionManager\x12S\n\x05\x43heck\x12\x14.prodvana.auth.Empty\x1a\x14.prodvana.auth.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/auth/session/check2\xa2\x04\n\x0f\x41piTokenManager\x12y\n\x11\x43reateOrgApiToken\x12\x14.prodvana.auth.Empty\x1a$.prodvana.auth.CreateOrgApiTokenResp\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/auth/api/create_org_token:\x01*\x12\x8a\x01\n\x12\x43reateOrgApiToken2\x12#.prodvana.auth.CreateOrgApiTokenReq\x1a$.prodvana.auth.CreateOrgApiTokenResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/auth/api/org_tokens/create:\x01*\x12\x88\x01\n\x11\x44\x65leteOrgApiToken\x12#.prodvana.auth.DeleteOrgApiTokenReq\x1a$.prodvana.auth.DeleteOrgApiTokenResp\"(\x82\xd3\xe4\x93\x02\"* /v1/auth/api/org_tokens/{name=*}\x12|\n\x10ListOrgApiTokens\x12\".prodvana.auth.ListOrgApiTokensReq\x1a#.prodvana.auth.ListOrgApiTokensResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/auth/api/org_tokensBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/authb\x06proto3')



_GETTOKENREQUEST = DESCRIPTOR.message_types_by_name['GetTokenRequest']
_GETAUTHURLRESPONSE = DESCRIPTOR.message_types_by_name['GetAuthUrlResponse']
_GETAUTHURLREQUEST = DESCRIPTOR.message_types_by_name['GetAuthUrlRequest']
_CLIAUTHREQ = DESCRIPTOR.message_types_by_name['CliAuthReq']
_CLIAUTHRESP = DESCRIPTOR.message_types_by_name['CliAuthResp']
_CLIAUTHRESP_USERPROMPT = _CLIAUTHRESP.nested_types_by_name['UserPrompt']
_REFRESHTOKENREQ = DESCRIPTOR.message_types_by_name['RefreshTokenReq']
_GETAUTHTOKENRESP = DESCRIPTOR.message_types_by_name['GetAuthTokenResp']
_EMPTY = DESCRIPTOR.message_types_by_name['Empty']
_CREATEORGAPITOKENREQ = DESCRIPTOR.message_types_by_name['CreateOrgApiTokenReq']
_CREATEORGAPITOKENRESP = DESCRIPTOR.message_types_by_name['CreateOrgApiTokenResp']
_DELETEORGAPITOKENREQ = DESCRIPTOR.message_types_by_name['DeleteOrgApiTokenReq']
_DELETEORGAPITOKENRESP = DESCRIPTOR.message_types_by_name['DeleteOrgApiTokenResp']
_LISTORGAPITOKENSREQ = DESCRIPTOR.message_types_by_name['ListOrgApiTokensReq']
_LISTORGAPITOKENSRESP = DESCRIPTOR.message_types_by_name['ListOrgApiTokensResp']
GetTokenRequest = _reflection.GeneratedProtocolMessageType('GetTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOKENREQUEST,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.GetTokenRequest)
  })
_sym_db.RegisterMessage(GetTokenRequest)

GetAuthUrlResponse = _reflection.GeneratedProtocolMessageType('GetAuthUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHURLRESPONSE,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.GetAuthUrlResponse)
  })
_sym_db.RegisterMessage(GetAuthUrlResponse)

GetAuthUrlRequest = _reflection.GeneratedProtocolMessageType('GetAuthUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHURLREQUEST,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.GetAuthUrlRequest)
  })
_sym_db.RegisterMessage(GetAuthUrlRequest)

CliAuthReq = _reflection.GeneratedProtocolMessageType('CliAuthReq', (_message.Message,), {
  'DESCRIPTOR' : _CLIAUTHREQ,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.CliAuthReq)
  })
_sym_db.RegisterMessage(CliAuthReq)

CliAuthResp = _reflection.GeneratedProtocolMessageType('CliAuthResp', (_message.Message,), {

  'UserPrompt' : _reflection.GeneratedProtocolMessageType('UserPrompt', (_message.Message,), {
    'DESCRIPTOR' : _CLIAUTHRESP_USERPROMPT,
    '__module__' : 'prodvana.auth.auth_manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.auth.CliAuthResp.UserPrompt)
    })
  ,
  'DESCRIPTOR' : _CLIAUTHRESP,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.CliAuthResp)
  })
_sym_db.RegisterMessage(CliAuthResp)
_sym_db.RegisterMessage(CliAuthResp.UserPrompt)

RefreshTokenReq = _reflection.GeneratedProtocolMessageType('RefreshTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENREQ,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.RefreshTokenReq)
  })
_sym_db.RegisterMessage(RefreshTokenReq)

GetAuthTokenResp = _reflection.GeneratedProtocolMessageType('GetAuthTokenResp', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHTOKENRESP,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.GetAuthTokenResp)
  })
_sym_db.RegisterMessage(GetAuthTokenResp)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.Empty)
  })
_sym_db.RegisterMessage(Empty)

CreateOrgApiTokenReq = _reflection.GeneratedProtocolMessageType('CreateOrgApiTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORGAPITOKENREQ,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.CreateOrgApiTokenReq)
  })
_sym_db.RegisterMessage(CreateOrgApiTokenReq)

CreateOrgApiTokenResp = _reflection.GeneratedProtocolMessageType('CreateOrgApiTokenResp', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORGAPITOKENRESP,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.CreateOrgApiTokenResp)
  })
_sym_db.RegisterMessage(CreateOrgApiTokenResp)

DeleteOrgApiTokenReq = _reflection.GeneratedProtocolMessageType('DeleteOrgApiTokenReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGAPITOKENREQ,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.DeleteOrgApiTokenReq)
  })
_sym_db.RegisterMessage(DeleteOrgApiTokenReq)

DeleteOrgApiTokenResp = _reflection.GeneratedProtocolMessageType('DeleteOrgApiTokenResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGAPITOKENRESP,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.DeleteOrgApiTokenResp)
  })
_sym_db.RegisterMessage(DeleteOrgApiTokenResp)

ListOrgApiTokensReq = _reflection.GeneratedProtocolMessageType('ListOrgApiTokensReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGAPITOKENSREQ,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.ListOrgApiTokensReq)
  })
_sym_db.RegisterMessage(ListOrgApiTokensReq)

ListOrgApiTokensResp = _reflection.GeneratedProtocolMessageType('ListOrgApiTokensResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGAPITOKENSRESP,
  '__module__' : 'prodvana.auth.auth_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.auth.ListOrgApiTokensResp)
  })
_sym_db.RegisterMessage(ListOrgApiTokensResp)

_AUTHMANAGER = DESCRIPTOR.services_by_name['AuthManager']
_AUTHSESSIONMANAGER = DESCRIPTOR.services_by_name['AuthSessionManager']
_APITOKENMANAGER = DESCRIPTOR.services_by_name['ApiTokenManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/auth'
  _AUTHMANAGER.methods_by_name['GetAuthToken']._options = None
  _AUTHMANAGER.methods_by_name['GetAuthToken']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/auth/get_token'
  _AUTHMANAGER.methods_by_name['GetAuthUrl']._options = None
  _AUTHMANAGER.methods_by_name['GetAuthUrl']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/auth/get_auth_url'
  _AUTHMANAGER.methods_by_name['RefreshToken']._options = None
  _AUTHMANAGER.methods_by_name['RefreshToken']._serialized_options = b'\202\323\344\223\002 \"\033/v1/auth/refresh_auth_token:\001*'
  _AUTHSESSIONMANAGER.methods_by_name['Check']._options = None
  _AUTHSESSIONMANAGER.methods_by_name['Check']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/auth/session/check'
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken']._options = None
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/auth/api/create_org_token:\001*'
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken2']._options = None
  _APITOKENMANAGER.methods_by_name['CreateOrgApiToken2']._serialized_options = b'\202\323\344\223\002#\"\036/v1/auth/api/org_tokens/create:\001*'
  _APITOKENMANAGER.methods_by_name['DeleteOrgApiToken']._options = None
  _APITOKENMANAGER.methods_by_name['DeleteOrgApiToken']._serialized_options = b'\202\323\344\223\002\"* /v1/auth/api/org_tokens/{name=*}'
  _APITOKENMANAGER.methods_by_name['ListOrgApiTokens']._options = None
  _APITOKENMANAGER.methods_by_name['ListOrgApiTokens']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/auth/api/org_tokens'
  _GETTOKENREQUEST._serialized_start=168
  _GETTOKENREQUEST._serialized_end=271
  _GETAUTHURLRESPONSE._serialized_start=273
  _GETAUTHURLRESPONSE._serialized_end=311
  _GETAUTHURLREQUEST._serialized_start=314
  _GETAUTHURLREQUEST._serialized_end=452
  _CLIAUTHREQ._serialized_start=454
  _CLIAUTHREQ._serialized_end=466
  _CLIAUTHRESP._serialized_start=469
  _CLIAUTHRESP._serialized_end=695
  _CLIAUTHRESP_USERPROMPT._serialized_start=589
  _CLIAUTHRESP_USERPROMPT._serialized_end=681
  _REFRESHTOKENREQ._serialized_start=697
  _REFRESHTOKENREQ._serialized_end=805
  _GETAUTHTOKENRESP._serialized_start=807
  _GETAUTHTOKENRESP._serialized_end=902
  _EMPTY._serialized_start=904
  _EMPTY._serialized_end=911
  _CREATEORGAPITOKENREQ._serialized_start=913
  _CREATEORGAPITOKENREQ._serialized_end=1025
  _CREATEORGAPITOKENRESP._serialized_start=1027
  _CREATEORGAPITOKENRESP._serialized_end=1112
  _DELETEORGAPITOKENREQ._serialized_start=1114
  _DELETEORGAPITOKENREQ._serialized_end=1150
  _DELETEORGAPITOKENRESP._serialized_start=1152
  _DELETEORGAPITOKENRESP._serialized_end=1175
  _LISTORGAPITOKENSREQ._serialized_start=1177
  _LISTORGAPITOKENSREQ._serialized_end=1198
  _LISTORGAPITOKENSRESP._serialized_start=1200
  _LISTORGAPITOKENSRESP._serialized_end=1267
  _AUTHMANAGER._serialized_start=1270
  _AUTHMANAGER._serialized_end=1697
  _AUTHSESSIONMANAGER._serialized_start=1699
  _AUTHSESSIONMANAGER._serialized_end=1804
  _APITOKENMANAGER._serialized_start=1807
  _APITOKENMANAGER._serialized_end=2353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/repo/repo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18prodvana/repo/repo.proto\x12\rprodvana.repo\"#\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"^\n\x06\x43ommit\x12\x11\n\tcommit_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\x13.prodvana.repo.User\"1\n\x0b\x46uzzyCommit\x12\x12\n\ncommit_ish\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\tBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repob\x06proto3')



_USER = DESCRIPTOR.message_types_by_name['User']
_COMMIT = DESCRIPTOR.message_types_by_name['Commit']
_FUZZYCOMMIT = DESCRIPTOR.message_types_by_name['FuzzyCommit']
User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.User)
  })
_sym_db.RegisterMessage(User)

Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), {
  'DESCRIPTOR' : _COMMIT,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.Commit)
  })
_sym_db.RegisterMessage(Commit)

FuzzyCommit = _reflection.GeneratedProtocolMessageType('FuzzyCommit', (_message.Message,), {
  'DESCRIPTOR' : _FUZZYCOMMIT,
  '__module__' : 'prodvana.repo.repo_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.repo.FuzzyCommit)
  })
_sym_db.RegisterMessage(FuzzyCommit)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/repo'
  _USER._serialized_start=43
  _USER._serialized_end=78
  _COMMIT._serialized_start=80
  _COMMIT._serialized_end=174
  _FUZZYCOMMIT._serialized_start=176
  _FUZZYCOMMIT._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/model/desired_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0prodvana/desired_state/model/desired_state.proto\x12\x1cprodvana.desired_state.model\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a$prodvana/common_config/program.proto\x1a\"prodvana/common_config/retry.proto\x1a!prodvana/common_config/task.proto\x1a#prodvana/environment/clusters.proto\x1a.prodvana/protection/protection_reference.proto\"p\n\x0eProtectionLink\x12;\n\tlifecycle\x18\x03 \x01(\x0b\x32(.prodvana.protection.ProtectionLifecycle\x12\x15\n\rattachment_id\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\x93\x06\n\tCondition\x12X\n\x07rc_cond\x18\x01 \x01(\x0b\x32\x45.prodvana.desired_state.model.Condition.ReleaseChannelStableConditionH\x00\x12Q\n\x0fmanual_approval\x18\x02 \x01(\x0b\x32\x36.prodvana.desired_state.model.Condition.ManualApprovalH\x00\x12\\\n\x0b\x63ustom_task\x18\x03 \x01(\x0b\x32\x45.prodvana.desired_state.model.Condition.CustomTaskSuccessfulConditionH\x00\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x1a\xa7\x01\n\x1dReleaseChannelStableCondition\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x12\n\nservice_id\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x05 \x01(\t\x12\x17\n\x0fservice_version\x18\x06 \x01(\t\x1a\x1f\n\x0eManualApproval\x12\r\n\x05topic\x18\x01 \x01(\t\x1a\x88\x02\n\x1d\x43ustomTaskSuccessfulCondition\x12\x18\n\x10\x63ustom_task_name\x18\x01 \x01(\t\x12\x66\n\nprotection\x18\x02 \x01(\x0b\x32P.prodvana.desired_state.model.Condition.CustomTaskSuccessfulCondition.ProtectionH\x00\x1a[\n\nProtection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\ttask_type\x18\x03 \x01(\x0e\x32,.prodvana.desired_state.model.CustomTaskTypeB\x08\n\x06sourceB\x0b\n\tcondition\"\xa0\x01\n\x11\x44\x65liveryExtension\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x38\n\tlifecycle\x18\x02 \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12<\n\nreferences\x18\x03 \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\"L\n\nIdentifier\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".prodvana.desired_state.model.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa1\x03\n\x08Metadata\x12>\n\rpreconditions\x18\x01 \x03(\x0b\x32\'.prodvana.desired_state.model.Condition\x12;\n\ninvariants\x18\x02 \x03(\x0b\x32\'.prodvana.desired_state.model.Condition\x12\x36\n\x04self\x18\x03 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x05 \x01(\t\x12\x46\n\x10protection_links\x18\x06 \x03(\x0b\x32,.prodvana.desired_state.model.ProtectionLink\x12L\n\x13\x64\x65livery_extensions\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.DeliveryExtensionJ\x04\x08\x07\x10\x08R\x0bprotections\"\xad\x01\n\x11StatusExplanation\x12\x39\n\x07subject\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12:\n\x06reason\x18\x02 \x01(\x0e\x32*.prodvana.desired_state.model.StatusReason\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x10\n\x08messages\x18\x04 \x03(\t\"\x8b\x01\n\x11\x41\x63tionExplanation\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x0b\x61\x63tion_type\x18\x02 \x01(\x0e\x32(.prodvana.desired_state.model.ActionType\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xcf\x01\n\x07Version\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x1a\n\x12\x61vailable_replicas\x18\x08 \x01(\x05\x12\x32\n\x0epush_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x17\n\x0ftarget_replicas\x18\x06 \x01(\x05J\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08R\tunhealthyR\x11unhealthy_reasons\"\x86\x03\n\x14ServiceInstanceState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x17\n\x0frelease_channel\x18\x04 \x01(\t\x12\x12\n\nservice_id\x18\x08 \x01(\t\x12\x1a\n\x12release_channel_id\x18\t \x01(\t\x12\x37\n\x08versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12?\n\x10rollback_version\x18\x06 \x01(\x0b\x32%.prodvana.desired_state.model.Version\x12\x10\n\x08rollback\x18\x07 \x01(\x08\x12=\n\x08\x64\x65livery\x18\n \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\"\xf0\x02\n\x0cServiceState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x05 \x01(\t\x12L\n\x10release_channels\x18\x06 \x03(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceState\x12\x43\n\x0c\x63ustom_tasks\x18\x07 \x03(\x0b\x32-.prodvana.desired_state.model.CustomTaskState\x12Q\n\x13\x64\x65livery_extensions\x18\t \x03(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionStateJ\x04\x08\x04\x10\x05J\x04\x08\x08\x10\t\"\xa5\x02\n\x11ServiceGroupState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12<\n\x08services\x18\x02 \x03(\x0b\x32*.prodvana.desired_state.model.ServiceState\x12\x43\n\x0c\x63ustom_tasks\x18\x03 \x03(\x0b\x32-.prodvana.desired_state.model.CustomTaskState\x12Q\n\x13\x64\x65livery_extensions\x18\x05 \x03(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionStateJ\x04\x08\x04\x10\x05\"\xa8\x02\n\x13\x43\x61naryProgressState\x12H\n\x06status\x18\x01 \x01(\x0e\x32\x38.prodvana.desired_state.model.CanaryProgressState.Status\x12 \n\rcanary_weight\x18\x02 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x64(\x00\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x15pause_start_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"=\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\r\n\tCOMPLETED\x10\x03\"\x94\x03\n\rDeliveryState\x12\x18\n\x10\x64\x65sired_state_id\x18\x0c \x01(\t\x12\x42\n\x06status\x18\x08 \x01(\x0e\x32\x32.prodvana.desired_state.model.DeliveryState.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12J\n\x0f\x63\x61nary_progress\x18\x0b \x03(\x0b\x32\x31.prodvana.desired_state.model.CanaryProgressState\x12\x11\n\tfirst_run\x18\r \x01(\x08\x12\x12\n\ngeneration\x18\x0e \x01(\t\"q\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x16\n\x12STATUS_PROGRESSING\x10\x01\x12\x11\n\rSTATUS_PAUSED\x10\x02\x12\x12\n\x0eSTATUS_HEALTHY\x10\x03\x12\x14\n\x10STATUS_UNHEALTHY\x10\x04J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"V\n\x1bRuntimeExtensionFetchOutput\x12\x37\n\x08versions\x18\x01 \x03(\x0b\x32%.prodvana.desired_state.model.Version\"\xa5\x07\n\rRuntimeObject\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x37\n\x08versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x42\n\x06status\x18\x06 \x01(\x0e\x32\x32.prodvana.desired_state.model.RuntimeObject.Status\x12?\n\x10rollback_version\x18\x07 \x01(\x0b\x32%.prodvana.desired_state.model.Version\x12=\n\x08\x64\x65livery\x18\x08 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\x12\x18\n\x10version_agnostic\x18\n \x01(\x08\x12\x0f\n\x07message\x18\x0c \x01(\t\x12W\n\x11runtime_extension\x18\r \x01(\x0b\x32<.prodvana.desired_state.model.RuntimeObject.RuntimeExtension\x12W\n\x0foutput_blob_ids\x18\x0e \x03(\x0b\x32>.prodvana.desired_state.model.RuntimeObject.OutputBlobIdsEntry\x12+\n\x08interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x65\n\x10RuntimeExtension\x12=\n\x05\x66\x65tch\x18\x01 \x01(\x0b\x32..prodvana.environment.CompiledExtensionCommand\x12\x12\n\nservice_id\x18\x02 \x01(\t\x1a\x34\n\x12OutputBlobIdsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02J\x04\x08\t\x10\nJ\x04\x08\x0b\x10\x0cR\x0eunhealthy_podsR\nstate_hash\"O\n\x0e\x43onditionState\x12=\n\x06status\x18\x01 \x01(\x0e\x32-.prodvana.desired_state.model.ConditionStatus\"\xde\x02\n\x0c\x43ontrolState\x12\x10\n\x08rollback\x18\x01 \x01(\x08\x12I\n\x13precondition_states\x18\x02 \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12\x46\n\x10invariant_states\x18\x03 \x03(\x0b\x32,.prodvana.desired_state.model.ConditionState\x12\x0e\n\x06paused\x18\x04 \x01(\x08\x12L\n\x13status_explanations\x18\x05 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12K\n\x12\x61\x63tion_explanation\x18\x06 \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation\"\x9e\x01\n\x13ManualApprovalState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x42\n\x06status\x18\x02 \x01(\x0e\x32\x32.prodvana.desired_state.model.ManualApprovalStatus\x12\r\n\x05topic\x18\x03 \x01(\t\"\xc1\x05\n\x05State\x12=\n\x07service\x18\x01 \x01(\x0b\x32*.prodvana.desired_state.model.ServiceStateH\x00\x12N\n\x10service_instance\x18\x02 \x01(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceStateH\x00\x12H\n\rservice_group\x18\x03 \x01(\x0b\x32/.prodvana.desired_state.model.ServiceGroupStateH\x00\x12\x45\n\x0eruntime_object\x18\x04 \x01(\x0b\x32+.prodvana.desired_state.model.RuntimeObjectH\x00\x12L\n\x0fmanual_approval\x18\x05 \x01(\x0b\x32\x31.prodvana.desired_state.model.ManualApprovalStateH\x00\x12\x44\n\x0b\x63ustom_task\x18\x06 \x01(\x0b\x32-.prodvana.desired_state.model.CustomTaskStateH\x00\x12S\n\x15protection_attachment\x18\x07 \x01(\x0b\x32\x32.prodvana.desired_state.model.ProtectionAttachmentH\x00\x12L\n\x0fprotection_link\x18\x08 \x01(\x0b\x32\x31.prodvana.desired_state.model.ProtectionLinkStateH\x00\x12R\n\x12\x64\x65livery_extension\x18\t \x01(\x0b\x32\x34.prodvana.desired_state.model.DeliveryExtensionStateH\x00\x42\r\n\x0bstate_oneof\"\x82\x01\n\x0b\x41nnotations\x12I\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x34.prodvana.desired_state.model.Annotations.Annotation\x1a(\n\nAnnotation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xae\x01\n\x18\x43ustomTaskExecutionState\x12>\n\x06status\x18\x01 \x01(\x0e\x32..prodvana.desired_state.model.CustomTaskStatus\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x03\x12@\n\x1clatest_attempt_end_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xce\x03\n\x0f\x43ustomTaskState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61pplication\x18\x04 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x05 \x01(\t\x12\x17\n\x0frelease_channel\x18\x06 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x07 \x01(\t\x12@\n\x07program\x18\t \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12J\n\ntask_state\x18\x0c \x01(\x0b\x32\x36.prodvana.desired_state.model.CustomTaskExecutionState\x12\x39\n\x0cretry_config\x18\r \x01(\x0b\x32#.prodvana.common_config.RetryConfig\x12\x13\n\x0bservice_ids\x18\x0e \x03(\tJ\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\xeb\x04\n\x13ProtectionLinkState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.prodvana.desired_state.model.ConditionStatus\x12:\n\x04link\x18\x03 \x01(\x0b\x32,.prodvana.desired_state.model.ProtectionLink\x12\x35\n\x11started_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11stopped_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x0estopped_reason\x18\x06 \x01(\x0e\x32<.prodvana.desired_state.model.ProtectionLinkState.StopReason\x12;\n\x17\x66irst_success_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa1\x01\n\nStopReason\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x17\n\x13LIFECYCLE_COMPLETED\x10\x01\x12\x12\n\x0eSUCCEEDED_ONCE\x10\x02\x12\x1a\n\x16SUCCEEDED_FOR_DURATION\x10\x03\x12\r\n\tTIMED_OUT\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0b\n\x07\x44\x45LETED\x10\x06\x12\x15\n\x11MANUALLY_BYPASSED\x10\x07\"\x89\x04\n\x14ProtectionAttachment\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x37\n\x08versions\x18\x02 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x46\n\x17last_completed_versions\x18\x05 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12<\n\x18last_completed_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x15last_completed_status\x18\x07 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12[\n\"last_completed_status_explanations\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12&\n\x1elast_completed_applied_version\x18\t \x01(\t\x12\x15\n\rprotection_id\x18\x03 \x01(\t\x12\x15\n\rattachment_id\x18\x04 \x01(\t\"\x81\x05\n\x16\x44\x65liveryExtensionState\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32&.prodvana.desired_state.model.Metadata\x12\x37\n\x08versions\x18\x02 \x03(\x0b\x32%.prodvana.desired_state.model.Version\x12\x14\n\x0c\x65xtension_id\x18\x03 \x01(\t\x12\x1d\n\x15\x65xtension_instance_id\x18\n \x01(\t\x12\x38\n\tlifecycle\x18\x0b \x01(\x0e\x32%.prodvana.common_config.TaskLifecycle\x12<\n\x18last_completed_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x15last_completed_status\x18\x07 \x01(\x0e\x32*.prodvana.desired_state.model.SimpleStatus\x12[\n\"last_completed_status_explanations\x18\x08 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\x12&\n\x1elast_completed_applied_version\x18\t \x01(\t\x12<\n\nreferences\x18\x0c \x03(\x0b\x32(.prodvana.desired_state.model.Identifier\x12=\n\x06status\x18\r \x01(\x0e\x32-.prodvana.desired_state.model.ConditionStatus\"\xc6\x02\n\x06Signal\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.prodvana.desired_state.model.SignalType\x12Z\n\x12\x64\x65livery_promotion\x18\x02 \x01(\x0b\x32<.prodvana.desired_state.model.Signal.DeliveryPromotionConfigH\x00\x12R\n\x11protection_bypass\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.Signal.ProtectionBypassH\x00\x1a\x36\n\x17\x44\x65liveryPromotionConfig\x12\r\n\x05stage\x18\x01 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x02 \x01(\x08\x1a\x12\n\x10ProtectionBypassB\x08\n\x06\x63onfig\"?\n\x08\x44\x65\x62ugLog\x12&\n\x02ts\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03log\x18\x02 \x01(\t*\xcb\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x14\n\x10SERVICE_INSTANCE\x10\x02\x12\x11\n\rSERVICE_GROUP\x10\x03\x12\x12\n\x0eRUNTIME_OBJECT\x10\x04\x12\x13\n\x0fMANUAL_APPROVAL\x10\x05\x12\x0f\n\x0b\x43USTOM_TASK\x10\x06\x12\x19\n\x15PROTECTION_ATTACHMENT\x10\x07\x12\x13\n\x0fPROTECTION_LINK\x10\x08\x12\x16\n\x12\x44\x45LIVERY_EXTENSION\x10\t*\x9a\x01\n\x0e\x43ustomTaskType\x12\x1c\n\x18\x43USTOM_TASK_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11PRE_APPROVAL_TASK\x10\x01\x12\x0c\n\x08\x41PPROVAL\x10\x02\x12\x16\n\x12POST_APPROVAL_TASK\x10\x03\x12\x13\n\x0f\x44\x45PLOYMENT_TASK\x10\x04\x12\x18\n\x14POST_DEPLOYMENT_TASK\x10\x05*\xf0\x01\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0e\n\nCONVERGING\x10\x01\x12\r\n\tCONVERGED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x10\n\x0cROLLING_BACK\x10\x04\x12\x0f\n\x0bROLLED_BACK\x10\x05\x12\x13\n\x0f\x46\x41ILED_ROLLBACK\x10\x0c\x12\n\n\x06PAUSED\x10\x06\x12\x10\n\x0c\x43HILD_PAUSED\x10\x07\x12\x19\n\x15WAITING_PRECONDITIONS\x10\x08\x12\x0c\n\x08REPLACED\x10\t\x12\x1b\n\x17WAITING_MANUAL_APPROVAL\x10\n\x12\x0b\n\x07\x44\x45LETED\x10\x0b*R\n\x0cSimpleStatus\x12\x0e\n\nSS_UNKNOWN\x10\x00\x12\x11\n\rSS_CONVERGING\x10\x01\x12\x10\n\x0cSS_CONVERGED\x10\x02\x12\r\n\tSS_FAILED\x10\x03*\xec\x01\n\x0cStatusReason\x12\x12\n\x0eREASON_UNKNOWN\x10\x00\x12\x14\n\x10NO_CURRENT_STATE\x10\x01\x12\x10\n\x0c\x41PPLY_FAILED\x10\x02\x12\x12\n\x0eUNHEALTHY_PODS\x10\x03\x12\x11\n\rUPDATING_PODS\x10\x04\x12\x14\n\x10VERSION_MISMATCH\x10\x05\x12\x19\n\x15RUNTIME_OBJECT_FAILED\x10\x06\x12\x18\n\x14PRECONDITIONS_FAILED\x10\x07\x12\x1c\n\x18MANUAL_APPROVAL_REJECTED\x10\x08\x12\x10\n\x0cSTUCK_ENTITY\x10\t*r\n\nActionType\x12\x17\n\x13\x41\x43TION_TYPE_UNKNOWN\x10\x00\x12\x18\n\x14\x41\x43TION_TYPE_APPLYING\x10\x01\x12\x17\n\x13\x41\x43TION_TYPE_APPLIED\x10\x02\x12\x18\n\x14\x41\x43TION_TYPE_COMPLETE\x10\x03*\x96\x01\n\x0f\x43onditionStatus\x12\x1c\n\x18\x43ONDITION_UNKNOWN_STATUS\x10\x00\x12\x15\n\x11\x43ONDITION_PENDING\x10\x01\x12\x17\n\x13\x43ONDITION_SATISFIED\x10\x02\x12\x1f\n\x1b\x43ONDITION_MANUALLY_BYPASSED\x10\x03\x12\x14\n\x10\x43ONDITION_FAILED\x10\x04*?\n\x14ManualApprovalStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02*\x85\x01\n\x10\x43ustomTaskStatus\x12\x17\n\x13\x43USTOM_TASK_PENDING\x10\x00\x12\x1a\n\x16\x43USTOM_TASK_SUCCESSFUL\x10\x01\x12!\n\x1d\x43USTOM_TASK_RETRIES_EXHAUSTED\x10\x02\x12\x19\n\x15\x43USTOM_TASK_TIMED_OUT\x10\x03*O\n\nSignalType\x12\x12\n\x0eSIGNAL_UNKNOWN\x10\x00\x12\x16\n\x12\x44\x45LIVERY_PROMOTION\x10\x01\x12\x15\n\x11PROTECTION_BYPASS\x10\x02\x42XZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/modelb\x06proto3')

_TYPE = DESCRIPTOR.enum_types_by_name['Type']
Type = enum_type_wrapper.EnumTypeWrapper(_TYPE)
_CUSTOMTASKTYPE = DESCRIPTOR.enum_types_by_name['CustomTaskType']
CustomTaskType = enum_type_wrapper.EnumTypeWrapper(_CUSTOMTASKTYPE)
_STATUS = DESCRIPTOR.enum_types_by_name['Status']
Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
_SIMPLESTATUS = DESCRIPTOR.enum_types_by_name['SimpleStatus']
SimpleStatus = enum_type_wrapper.EnumTypeWrapper(_SIMPLESTATUS)
_STATUSREASON = DESCRIPTOR.enum_types_by_name['StatusReason']
StatusReason = enum_type_wrapper.EnumTypeWrapper(_STATUSREASON)
_ACTIONTYPE = DESCRIPTOR.enum_types_by_name['ActionType']
ActionType = enum_type_wrapper.EnumTypeWrapper(_ACTIONTYPE)
_CONDITIONSTATUS = DESCRIPTOR.enum_types_by_name['ConditionStatus']
ConditionStatus = enum_type_wrapper.EnumTypeWrapper(_CONDITIONSTATUS)
_MANUALAPPROVALSTATUS = DESCRIPTOR.enum_types_by_name['ManualApprovalStatus']
ManualApprovalStatus = enum_type_wrapper.EnumTypeWrapper(_MANUALAPPROVALSTATUS)
_CUSTOMTASKSTATUS = DESCRIPTOR.enum_types_by_name['CustomTaskStatus']
CustomTaskStatus = enum_type_wrapper.EnumTypeWrapper(_CUSTOMTASKSTATUS)
_SIGNALTYPE = DESCRIPTOR.enum_types_by_name['SignalType']
SignalType = enum_type_wrapper.EnumTypeWrapper(_SIGNALTYPE)
UNKNOWN = 0
SERVICE = 1
SERVICE_INSTANCE = 2
SERVICE_GROUP = 3
RUNTIME_OBJECT = 4
MANUAL_APPROVAL = 5
CUSTOM_TASK = 6
PROTECTION_ATTACHMENT = 7
PROTECTION_LINK = 8
DELIVERY_EXTENSION = 9
CUSTOM_TASK_TYPE_UNKNOWN = 0
PRE_APPROVAL_TASK = 1
APPROVAL = 2
POST_APPROVAL_TASK = 3
DEPLOYMENT_TASK = 4
POST_DEPLOYMENT_TASK = 5
UNKNOWN_STATUS = 0
CONVERGING = 1
CONVERGED = 2
FAILED = 3
ROLLING_BACK = 4
ROLLED_BACK = 5
FAILED_ROLLBACK = 12
PAUSED = 6
CHILD_PAUSED = 7
WAITING_PRECONDITIONS = 8
REPLACED = 9
WAITING_MANUAL_APPROVAL = 10
DELETED = 11
SS_UNKNOWN = 0
SS_CONVERGING = 1
SS_CONVERGED = 2
SS_FAILED = 3
REASON_UNKNOWN = 0
NO_CURRENT_STATE = 1
APPLY_FAILED = 2
UNHEALTHY_PODS = 3
UPDATING_PODS = 4
VERSION_MISMATCH = 5
RUNTIME_OBJECT_FAILED = 6
PRECONDITIONS_FAILED = 7
MANUAL_APPROVAL_REJECTED = 8
STUCK_ENTITY = 9
ACTION_TYPE_UNKNOWN = 0
ACTION_TYPE_APPLYING = 1
ACTION_TYPE_APPLIED = 2
ACTION_TYPE_COMPLETE = 3
CONDITION_UNKNOWN_STATUS = 0
CONDITION_PENDING = 1
CONDITION_SATISFIED = 2
CONDITION_MANUALLY_BYPASSED = 3
CONDITION_FAILED = 4
PENDING = 0
APPROVED = 1
REJECTED = 2
CUSTOM_TASK_PENDING = 0
CUSTOM_TASK_SUCCESSFUL = 1
CUSTOM_TASK_RETRIES_EXHAUSTED = 2
CUSTOM_TASK_TIMED_OUT = 3
SIGNAL_UNKNOWN = 0
DELIVERY_PROMOTION = 1
PROTECTION_BYPASS = 2


_PROTECTIONLINK = DESCRIPTOR.message_types_by_name['ProtectionLink']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
_CONDITION_RELEASECHANNELSTABLECONDITION = _CONDITION.nested_types_by_name['ReleaseChannelStableCondition']
_CONDITION_MANUALAPPROVAL = _CONDITION.nested_types_by_name['ManualApproval']
_CONDITION_CUSTOMTASKSUCCESSFULCONDITION = _CONDITION.nested_types_by_name['CustomTaskSuccessfulCondition']
_CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION = _CONDITION_CUSTOMTASKSUCCESSFULCONDITION.nested_types_by_name['Protection']
_DELIVERYEXTENSION = DESCRIPTOR.message_types_by_name['DeliveryExtension']
_IDENTIFIER = DESCRIPTOR.message_types_by_name['Identifier']
_METADATA = DESCRIPTOR.message_types_by_name['Metadata']
_STATUSEXPLANATION = DESCRIPTOR.message_types_by_name['StatusExplanation']
_ACTIONEXPLANATION = DESCRIPTOR.message_types_by_name['ActionExplanation']
_VERSION = DESCRIPTOR.message_types_by_name['Version']
_SERVICEINSTANCESTATE = DESCRIPTOR.message_types_by_name['ServiceInstanceState']
_SERVICESTATE = DESCRIPTOR.message_types_by_name['ServiceState']
_SERVICEGROUPSTATE = DESCRIPTOR.message_types_by_name['ServiceGroupState']
_CANARYPROGRESSSTATE = DESCRIPTOR.message_types_by_name['CanaryProgressState']
_DELIVERYSTATE = DESCRIPTOR.message_types_by_name['DeliveryState']
_RUNTIMEEXTENSIONFETCHOUTPUT = DESCRIPTOR.message_types_by_name['RuntimeExtensionFetchOutput']
_RUNTIMEOBJECT = DESCRIPTOR.message_types_by_name['RuntimeObject']
_RUNTIMEOBJECT_RUNTIMEEXTENSION = _RUNTIMEOBJECT.nested_types_by_name['RuntimeExtension']
_RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY = _RUNTIMEOBJECT.nested_types_by_name['OutputBlobIdsEntry']
_CONDITIONSTATE = DESCRIPTOR.message_types_by_name['ConditionState']
_CONTROLSTATE = DESCRIPTOR.message_types_by_name['ControlState']
_MANUALAPPROVALSTATE = DESCRIPTOR.message_types_by_name['ManualApprovalState']
_STATE = DESCRIPTOR.message_types_by_name['State']
_ANNOTATIONS = DESCRIPTOR.message_types_by_name['Annotations']
_ANNOTATIONS_ANNOTATION = _ANNOTATIONS.nested_types_by_name['Annotation']
_CUSTOMTASKEXECUTIONSTATE = DESCRIPTOR.message_types_by_name['CustomTaskExecutionState']
_CUSTOMTASKSTATE = DESCRIPTOR.message_types_by_name['CustomTaskState']
_PROTECTIONLINKSTATE = DESCRIPTOR.message_types_by_name['ProtectionLinkState']
_PROTECTIONATTACHMENT = DESCRIPTOR.message_types_by_name['ProtectionAttachment']
_DELIVERYEXTENSIONSTATE = DESCRIPTOR.message_types_by_name['DeliveryExtensionState']
_SIGNAL = DESCRIPTOR.message_types_by_name['Signal']
_SIGNAL_DELIVERYPROMOTIONCONFIG = _SIGNAL.nested_types_by_name['DeliveryPromotionConfig']
_SIGNAL_PROTECTIONBYPASS = _SIGNAL.nested_types_by_name['ProtectionBypass']
_DEBUGLOG = DESCRIPTOR.message_types_by_name['DebugLog']
_CANARYPROGRESSSTATE_STATUS = _CANARYPROGRESSSTATE.enum_types_by_name['Status']
_DELIVERYSTATE_STATUS = _DELIVERYSTATE.enum_types_by_name['Status']
_RUNTIMEOBJECT_STATUS = _RUNTIMEOBJECT.enum_types_by_name['Status']
_PROTECTIONLINKSTATE_STOPREASON = _PROTECTIONLINKSTATE.enum_types_by_name['StopReason']
ProtectionLink = _reflection.GeneratedProtocolMessageType('ProtectionLink', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONLINK,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ProtectionLink)
  })
_sym_db.RegisterMessage(ProtectionLink)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {

  'ReleaseChannelStableCondition' : _reflection.GeneratedProtocolMessageType('ReleaseChannelStableCondition', (_message.Message,), {
    'DESCRIPTOR' : _CONDITION_RELEASECHANNELSTABLECONDITION,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Condition.ReleaseChannelStableCondition)
    })
  ,

  'ManualApproval' : _reflection.GeneratedProtocolMessageType('ManualApproval', (_message.Message,), {
    'DESCRIPTOR' : _CONDITION_MANUALAPPROVAL,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Condition.ManualApproval)
    })
  ,

  'CustomTaskSuccessfulCondition' : _reflection.GeneratedProtocolMessageType('CustomTaskSuccessfulCondition', (_message.Message,), {

    'Protection' : _reflection.GeneratedProtocolMessageType('Protection', (_message.Message,), {
      'DESCRIPTOR' : _CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION,
      '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Condition.CustomTaskSuccessfulCondition.Protection)
      })
    ,
    'DESCRIPTOR' : _CONDITION_CUSTOMTASKSUCCESSFULCONDITION,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Condition.CustomTaskSuccessfulCondition)
    })
  ,
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Condition)
  })
_sym_db.RegisterMessage(Condition)
_sym_db.RegisterMessage(Condition.ReleaseChannelStableCondition)
_sym_db.RegisterMessage(Condition.ManualApproval)
_sym_db.RegisterMessage(Condition.CustomTaskSuccessfulCondition)
_sym_db.RegisterMessage(Condition.CustomTaskSuccessfulCondition.Protection)

DeliveryExtension = _reflection.GeneratedProtocolMessageType('DeliveryExtension', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYEXTENSION,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.DeliveryExtension)
  })
_sym_db.RegisterMessage(DeliveryExtension)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

StatusExplanation = _reflection.GeneratedProtocolMessageType('StatusExplanation', (_message.Message,), {
  'DESCRIPTOR' : _STATUSEXPLANATION,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.StatusExplanation)
  })
_sym_db.RegisterMessage(StatusExplanation)

ActionExplanation = _reflection.GeneratedProtocolMessageType('ActionExplanation', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONEXPLANATION,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ActionExplanation)
  })
_sym_db.RegisterMessage(ActionExplanation)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Version)
  })
_sym_db.RegisterMessage(Version)

ServiceInstanceState = _reflection.GeneratedProtocolMessageType('ServiceInstanceState', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCESTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ServiceInstanceState)
  })
_sym_db.RegisterMessage(ServiceInstanceState)

ServiceState = _reflection.GeneratedProtocolMessageType('ServiceState', (_message.Message,), {
  'DESCRIPTOR' : _SERVICESTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ServiceState)
  })
_sym_db.RegisterMessage(ServiceState)

ServiceGroupState = _reflection.GeneratedProtocolMessageType('ServiceGroupState', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEGROUPSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ServiceGroupState)
  })
_sym_db.RegisterMessage(ServiceGroupState)

CanaryProgressState = _reflection.GeneratedProtocolMessageType('CanaryProgressState', (_message.Message,), {
  'DESCRIPTOR' : _CANARYPROGRESSSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.CanaryProgressState)
  })
_sym_db.RegisterMessage(CanaryProgressState)

DeliveryState = _reflection.GeneratedProtocolMessageType('DeliveryState', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.DeliveryState)
  })
_sym_db.RegisterMessage(DeliveryState)

RuntimeExtensionFetchOutput = _reflection.GeneratedProtocolMessageType('RuntimeExtensionFetchOutput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEEXTENSIONFETCHOUTPUT,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.RuntimeExtensionFetchOutput)
  })
_sym_db.RegisterMessage(RuntimeExtensionFetchOutput)

RuntimeObject = _reflection.GeneratedProtocolMessageType('RuntimeObject', (_message.Message,), {

  'RuntimeExtension' : _reflection.GeneratedProtocolMessageType('RuntimeExtension', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMEOBJECT_RUNTIMEEXTENSION,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.RuntimeObject.RuntimeExtension)
    })
  ,

  'OutputBlobIdsEntry' : _reflection.GeneratedProtocolMessageType('OutputBlobIdsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.RuntimeObject.OutputBlobIdsEntry)
    })
  ,
  'DESCRIPTOR' : _RUNTIMEOBJECT,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.RuntimeObject)
  })
_sym_db.RegisterMessage(RuntimeObject)
_sym_db.RegisterMessage(RuntimeObject.RuntimeExtension)
_sym_db.RegisterMessage(RuntimeObject.OutputBlobIdsEntry)

ConditionState = _reflection.GeneratedProtocolMessageType('ConditionState', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ConditionState)
  })
_sym_db.RegisterMessage(ConditionState)

ControlState = _reflection.GeneratedProtocolMessageType('ControlState', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ControlState)
  })
_sym_db.RegisterMessage(ControlState)

ManualApprovalState = _reflection.GeneratedProtocolMessageType('ManualApprovalState', (_message.Message,), {
  'DESCRIPTOR' : _MANUALAPPROVALSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ManualApprovalState)
  })
_sym_db.RegisterMessage(ManualApprovalState)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
  'DESCRIPTOR' : _STATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.State)
  })
_sym_db.RegisterMessage(State)

Annotations = _reflection.GeneratedProtocolMessageType('Annotations', (_message.Message,), {

  'Annotation' : _reflection.GeneratedProtocolMessageType('Annotation', (_message.Message,), {
    'DESCRIPTOR' : _ANNOTATIONS_ANNOTATION,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Annotations.Annotation)
    })
  ,
  'DESCRIPTOR' : _ANNOTATIONS,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Annotations)
  })
_sym_db.RegisterMessage(Annotations)
_sym_db.RegisterMessage(Annotations.Annotation)

CustomTaskExecutionState = _reflection.GeneratedProtocolMessageType('CustomTaskExecutionState', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTASKEXECUTIONSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.CustomTaskExecutionState)
  })
_sym_db.RegisterMessage(CustomTaskExecutionState)

CustomTaskState = _reflection.GeneratedProtocolMessageType('CustomTaskState', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTASKSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.CustomTaskState)
  })
_sym_db.RegisterMessage(CustomTaskState)

ProtectionLinkState = _reflection.GeneratedProtocolMessageType('ProtectionLinkState', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONLINKSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ProtectionLinkState)
  })
_sym_db.RegisterMessage(ProtectionLinkState)

ProtectionAttachment = _reflection.GeneratedProtocolMessageType('ProtectionAttachment', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONATTACHMENT,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.ProtectionAttachment)
  })
_sym_db.RegisterMessage(ProtectionAttachment)

DeliveryExtensionState = _reflection.GeneratedProtocolMessageType('DeliveryExtensionState', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYEXTENSIONSTATE,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.DeliveryExtensionState)
  })
_sym_db.RegisterMessage(DeliveryExtensionState)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), {

  'DeliveryPromotionConfig' : _reflection.GeneratedProtocolMessageType('DeliveryPromotionConfig', (_message.Message,), {
    'DESCRIPTOR' : _SIGNAL_DELIVERYPROMOTIONCONFIG,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Signal.DeliveryPromotionConfig)
    })
  ,

  'ProtectionBypass' : _reflection.GeneratedProtocolMessageType('ProtectionBypass', (_message.Message,), {
    'DESCRIPTOR' : _SIGNAL_PROTECTIONBYPASS,
    '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Signal.ProtectionBypass)
    })
  ,
  'DESCRIPTOR' : _SIGNAL,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.Signal)
  })
_sym_db.RegisterMessage(Signal)
_sym_db.RegisterMessage(Signal.DeliveryPromotionConfig)
_sym_db.RegisterMessage(Signal.ProtectionBypass)

DebugLog = _reflection.GeneratedProtocolMessageType('DebugLog', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGLOG,
  '__module__' : 'prodvana.desired_state.model.desired_state_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.model.DebugLog)
  })
_sym_db.RegisterMessage(DebugLog)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/model'
  _CANARYPROGRESSSTATE.fields_by_name['canary_weight']._options = None
  _CANARYPROGRESSSTATE.fields_by_name['canary_weight']._serialized_options = b'\372B\006\032\004\030d(\000'
  _RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY._options = None
  _RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY._serialized_options = b'8\001'
  _CUSTOMTASKSTATE.fields_by_name['name']._options = None
  _CUSTOMTASKSTATE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CUSTOMTASKSTATE.fields_by_name['description']._options = None
  _CUSTOMTASKSTATE.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _CUSTOMTASKSTATE.fields_by_name['program']._options = None
  _CUSTOMTASKSTATE.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TYPE._serialized_start=9512
  _TYPE._serialized_end=9715
  _CUSTOMTASKTYPE._serialized_start=9718
  _CUSTOMTASKTYPE._serialized_end=9872
  _STATUS._serialized_start=9875
  _STATUS._serialized_end=10115
  _SIMPLESTATUS._serialized_start=10117
  _SIMPLESTATUS._serialized_end=10199
  _STATUSREASON._serialized_start=10202
  _STATUSREASON._serialized_end=10438
  _ACTIONTYPE._serialized_start=10440
  _ACTIONTYPE._serialized_end=10554
  _CONDITIONSTATUS._serialized_start=10557
  _CONDITIONSTATUS._serialized_end=10707
  _MANUALAPPROVALSTATUS._serialized_start=10709
  _MANUALAPPROVALSTATUS._serialized_end=10772
  _CUSTOMTASKSTATUS._serialized_start=10775
  _CUSTOMTASKSTATUS._serialized_end=10908
  _SIGNALTYPE._serialized_start=10910
  _SIGNALTYPE._serialized_end=10989
  _PROTECTIONLINK._serialized_start=366
  _PROTECTIONLINK._serialized_end=478
  _CONDITION._serialized_start=481
  _CONDITION._serialized_end=1268
  _CONDITION_RELEASECHANNELSTABLECONDITION._serialized_start=788
  _CONDITION_RELEASECHANNELSTABLECONDITION._serialized_end=955
  _CONDITION_MANUALAPPROVAL._serialized_start=957
  _CONDITION_MANUALAPPROVAL._serialized_end=988
  _CONDITION_CUSTOMTASKSUCCESSFULCONDITION._serialized_start=991
  _CONDITION_CUSTOMTASKSUCCESSFULCONDITION._serialized_end=1255
  _CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION._serialized_start=1154
  _CONDITION_CUSTOMTASKSUCCESSFULCONDITION_PROTECTION._serialized_end=1245
  _DELIVERYEXTENSION._serialized_start=1271
  _DELIVERYEXTENSION._serialized_end=1431
  _IDENTIFIER._serialized_start=1433
  _IDENTIFIER._serialized_end=1509
  _METADATA._serialized_start=1512
  _METADATA._serialized_end=1929
  _STATUSEXPLANATION._serialized_start=1932
  _STATUSEXPLANATION._serialized_end=2105
  _ACTIONEXPLANATION._serialized_start=2108
  _ACTIONEXPLANATION._serialized_end=2247
  _VERSION._serialized_start=2250
  _VERSION._serialized_end=2457
  _SERVICEINSTANCESTATE._serialized_start=2460
  _SERVICEINSTANCESTATE._serialized_end=2850
  _SERVICESTATE._serialized_start=2853
  _SERVICESTATE._serialized_end=3221
  _SERVICEGROUPSTATE._serialized_start=3224
  _SERVICEGROUPSTATE._serialized_end=3517
  _CANARYPROGRESSSTATE._serialized_start=3520
  _CANARYPROGRESSSTATE._serialized_end=3816
  _CANARYPROGRESSSTATE_STATUS._serialized_start=3755
  _CANARYPROGRESSSTATE_STATUS._serialized_end=3816
  _DELIVERYSTATE._serialized_start=3819
  _DELIVERYSTATE._serialized_end=4223
  _DELIVERYSTATE_STATUS._serialized_start=4062
  _DELIVERYSTATE_STATUS._serialized_end=4175
  _RUNTIMEEXTENSIONFETCHOUTPUT._serialized_start=4225
  _RUNTIMEEXTENSIONFETCHOUTPUT._serialized_end=4311
  _RUNTIMEOBJECT._serialized_start=4314
  _RUNTIMEOBJECT._serialized_end=5247
  _RUNTIMEOBJECT_RUNTIMEEXTENSION._serialized_start=5002
  _RUNTIMEOBJECT_RUNTIMEEXTENSION._serialized_end=5103
  _RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY._serialized_start=5105
  _RUNTIMEOBJECT_OUTPUTBLOBIDSENTRY._serialized_end=5157
  _RUNTIMEOBJECT_STATUS._serialized_start=5159
  _RUNTIMEOBJECT_STATUS._serialized_end=5207
  _CONDITIONSTATE._serialized_start=5249
  _CONDITIONSTATE._serialized_end=5328
  _CONTROLSTATE._serialized_start=5331
  _CONTROLSTATE._serialized_end=5681
  _MANUALAPPROVALSTATE._serialized_start=5684
  _MANUALAPPROVALSTATE._serialized_end=5842
  _STATE._serialized_start=5845
  _STATE._serialized_end=6550
  _ANNOTATIONS._serialized_start=6553
  _ANNOTATIONS._serialized_end=6683
  _ANNOTATIONS_ANNOTATION._serialized_start=6643
  _ANNOTATIONS_ANNOTATION._serialized_end=6683
  _CUSTOMTASKEXECUTIONSTATE._serialized_start=6686
  _CUSTOMTASKEXECUTIONSTATE._serialized_end=6860
  _CUSTOMTASKSTATE._serialized_start=6863
  _CUSTOMTASKSTATE._serialized_end=7325
  _PROTECTIONLINKSTATE._serialized_start=7328
  _PROTECTIONLINKSTATE._serialized_end=7947
  _PROTECTIONLINKSTATE_STOPREASON._serialized_start=7786
  _PROTECTIONLINKSTATE_STOPREASON._serialized_end=7947
  _PROTECTIONATTACHMENT._serialized_start=7950
  _PROTECTIONATTACHMENT._serialized_end=8471
  _DELIVERYEXTENSIONSTATE._serialized_start=8474
  _DELIVERYEXTENSIONSTATE._serialized_end=9115
  _SIGNAL._serialized_start=9118
  _SIGNAL._serialized_end=9444
  _SIGNAL_DELIVERYPROMOTIONCONFIG._serialized_start=9360
  _SIGNAL_DELIVERYPROMOTIONCONFIG._serialized_end=9414
  _SIGNAL_PROTECTIONBYPASS._serialized_start=9416
  _SIGNAL_PROTECTIONBYPASS._serialized_end=9434
  _DEBUGLOG._serialized_start=9446
  _DEBUGLOG._serialized_end=9509
# @@protoc_insertion_point(module_scope)
